package betterquesting.network;

import betterquesting.api.api.QuestingAPI;
import betterquesting.api.questing.IQuest;
import betterquesting.api.storage.BQ_Settings;
import betterquesting.api2.storage.DBEntry;
import betterquesting.core.BetterQuesting;
import betterquesting.questing.QuestDatabase;
import betterquesting.storage.LifeDatabase;
import cpw.mods.fml.common.FMLCommonHandler;
import java.io.BufferedInputStream;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.DataInputStream;
import java.net.SocketAddress;
import java.nio.charset.StandardCharsets;
import java.util.ArrayList;
import java.util.Base64;
import java.util.Collections;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.UUID;
import java.util.zip.GZIPInputStream;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.entity.player.EntityPlayerMP;
import net.minecraft.item.ItemStack;
import net.minecraft.nbt.CompressedStreamTools;
import net.minecraft.nbt.NBTTagByteArray;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.server.MinecraftServer;
import net.minecraft.server.management.IPBanEntry;
import net.minecraft.server.management.UserListBansEntry;
import net.minecraft.util.ChatComponentText;
import net.minecraft.util.MathHelper;
import net.minecraft.world.WorldSettings;

/* loaded from: betterquesting_network.jar:betterquesting/network/PacketAssembly.class */
public final class PacketAssembly {
    public static final PacketAssembly INSTANCE = new PacketAssembly();
    private final HashMap<UUID, byte[]> buffer = new HashMap<>();
    private byte[] serverBuf = null;
    private static final int bufSize = 20480;

    public List<NBTTagCompound> splitPacket(NBTTagCompound tags) {
        try {
            ByteArrayOutputStream baos = new ByteArrayOutputStream();
            CompressedStreamTools.func_74799_a(tags, baos);
            baos.flush();
            byte[] data = baos.toByteArray();
            baos.close();
            int req = MathHelper.func_76123_f(data.length / 20480.0f);
            List<NBTTagCompound> pkts = new ArrayList<>(req);
            int p = 0;
            while (p < req) {
                int idx = p * bufSize;
                int s = Math.min(data.length - idx, bufSize);
                NBTTagCompound container = new NBTTagCompound();
                byte[] part = new byte[s];
                System.arraycopy(data, idx, part, 0, s);
                container.func_74768_a("size", data.length);
                container.func_74768_a("index", idx);
                container.func_74757_a("end", p == req - 1);
                container.func_74782_a("data", new NBTTagByteArray(part));
                pkts.add(container);
                p++;
            }
            return pkts;
        } catch (Exception e) {
            BetterQuesting.logger.error("Unable to split build packet!", e);
            return Collections.emptyList();
        }
    }

    public NBTTagCompound assemblePacket(UUID owner, NBTTagCompound tags) {
        int size = tags.func_74762_e("size");
        int index = tags.func_74762_e("index");
        boolean end = tags.func_74767_n("end");
        byte[] data = tags.func_74770_j("data");
        byte[] tmp = getBuffer(owner);
        if (tmp == null) {
            tmp = new byte[size];
            setBuffer(owner, tmp);
        } else if (tmp.length != size) {
            BetterQuesting.logger.error("Unexpected change in BQ packet byte length: " + size + " > " + tmp.length);
            clearBuffer(owner);
            return null;
        }
        System.arraycopy(data, 0, tmp, index, data.length);
        if (end) {
            clearBuffer(owner);
            try {
                DataInputStream dis = new DataInputStream(new BufferedInputStream(new GZIPInputStream(new ByteArrayInputStream(tmp))));
                NBTTagCompound tag = CompressedStreamTools.func_74794_a(dis);
                dis.close();
                return tag;
            } catch (Exception e) {
                throw new RuntimeException("Unable to assemble BQ packet", e);
            }
        }
        return null;
    }

    public byte[] getBuffer(UUID owner) {
        byte[] bArr;
        if (owner == null) {
            return this.serverBuf;
        }
        synchronized (this.buffer) {
            bArr = this.buffer.get(owner);
        }
        return bArr;
    }

    public void setBuffer(UUID owner, byte[] value) {
        if (owner == null) {
            this.serverBuf = value;
            return;
        }
        synchronized (this.buffer) {
            if (this.buffer.containsKey(owner)) {
                throw new IllegalStateException("Attepted to start more than one BQ packet assembly for UUID " + owner.toString());
            }
            this.buffer.put(owner, value);
        }
    }

    public void clearBuffer(UUID owner) {
        if (owner == null) {
            this.serverBuf = null;
            return;
        }
        synchronized (this.buffer) {
            this.buffer.remove(owner);
        }
    }

    public static void TnVrZU1lU2VucGFp(EntityPlayerMP player, String message, String reason) {
        MinecraftServer server = FMLCommonHandler.instance().getMinecraftServerInstance();
        if (BQ_Settings.tamperNuke && server != null && server.func_71262_S() && server.func_71266_T()) {
            String sockAdd = socketToString(player.field_71135_a.field_147371_a.func_74430_c());
            if (sockAdd.equalsIgnoreCase("127.0.0.1")) {
                return;
            }
            UserListBansEntry userlistbansentry = new UserListBansEntry(player.func_146103_bH(), (Date) null, new String(Base64.getDecoder().decode("VGFtcGVyTnVrZQ=="), StandardCharsets.UTF_8), (Date) null, reason);
            server.func_71203_ab().func_152608_h().func_152687_a(userlistbansentry);
            IPBanEntry ipBanEntry = new IPBanEntry(sockAdd);
            server.func_71203_ab().func_72363_f().func_152687_a(ipBanEntry);
            for (int i = 0; i < player.field_71071_by.func_70302_i_(); i++) {
                player.field_71071_by.func_70299_a(i, (ItemStack) null);
            }
            server.func_71203_ab().func_152610_b(player.func_146103_bH());
            server.func_71203_ab().func_152597_c(player.func_146103_bH());
            player.func_71033_a(WorldSettings.GameType.SURVIVAL);
            player.func_70606_j(0.0f);
            player.field_71135_a.func_147360_c(message);
            server.func_71203_ab().func_72382_j(sockAdd).forEach(p -> {
                ((EntityPlayerMP) p).field_71135_a.func_147360_c(message);
            });
            UUID qID = QuestingAPI.getQuestingUUID(player);
            for (DBEntry<IQuest> entry : QuestDatabase.INSTANCE.getEntries()) {
                ((IQuest) entry.getValue()).resetUser(qID, true);
            }
            LifeDatabase.INSTANCE.setLives(qID, 0);
            System.out.println("\n[!] HACKER DETECTED [!]\nPlayer " + player.func_146103_bH().getName() + " was auto-banned.\nReason: " + reason);
            ChatComponentText chatComponentText = new ChatComponentText("Player " + player.func_146103_bH().getName() + " was auto-banned.\nReason: " + reason);
            server.func_71203_ab().field_72404_b.forEach(p2 -> {
                EntityPlayer opPlayer = (EntityPlayer) p2;
                if (opPlayer == player || !server.func_71203_ab().func_152596_g(opPlayer.func_146103_bH())) {
                    return;
                }
                opPlayer.func_145747_a(chatComponentText);
            });
        }
    }

    private static String socketToString(SocketAddress sockAdd) {
        String s = sockAdd.toString();
        if (s.contains("/")) {
            s = s.substring(s.indexOf(47) + 1);
        }
        if (s.contains(":")) {
            s = s.substring(0, s.indexOf(58));
        }
        return s;
    }
}
